@@ -1,4 +1,4 @@
-SCALA_212_VERSION <- "2.12.4"
+SCALA_212_VERSION <- "2.12.5"
 SCALA_211_VERSION <- "2.11.12"
 
 findJava <- function() {  ## Mimic how the 'scala' shell script finds Java.
@@ -30,14 +30,17 @@ latestVersion <- function(major.release) {
 
 javaVersion <- function(javaCmd) {
   response <- system2(javaCmd,"-version",stdout=TRUE,stderr=TRUE)
-  regexp <- '(java|openjdk) version "(.*)"'
+  regexp <- '(java|openjdk) version "([^"]*)".*'
   line <- response[grepl(regexp,response)]
   if ( length(line) != 1 ) stop(paste0("Cannot determine Java version.\n",paste(response,collapse="\n")))
   versionString <- gsub(regexp,"\\2",line)
   versionParts <- strsplit(versionString,"\\.")[[1]]
-  if ( versionParts[1] != '1' ) stop(paste0("Unexpected Java version.\n",paste(response,collapse="\n")))
-  versionNumber <- as.numeric(versionParts[2])
-  if ( ! ( versionNumber %in% c(6,7,8) ) ) stop(paste0("Unsupported Java version.\n",paste(response,collapse="\n")))
+  versionNumber <- if ( versionParts[1] == '1' ) {
+    as.numeric(versionParts[2])
+  } else {
+    as.numeric(versionParts[1])
+  }
+  if ( ! ( versionNumber %in% c(7,8,9,10,11) ) ) stop(paste0("Unsupported Java version.\n",paste(response,collapse="\n")))
   versionNumber
 }
 
@@ -46,8 +49,11 @@ scalaInstall <- function(major.release=c("2.11","2.12"), global=FALSE) {
   if ( length(major.release) == 0 ) stop("At least one major release must be supplied.")
   javaVersion <- javaVersion(findJava())
   if ( ( javaVersion <= 7 ) && ( compareVersion("2.11",major.release) < 0 ) ) {
-    cat("It appears you are using an old version of Java, so Scala 2.11 will be installed.\n")
+    cat("It appears you are using an Java version <= 7, so Scala 2.11 will be installed.\n")
     return(scalaInstall("2.11", global=global))
+  } else if ( ( javaVersion >= 9 ) && ( compareVersion("2.12",major.release) > 0 ) ) {
+    cat("It appears you are using an Java version >= 9, so Scala 2.12 will be installed.\n")
+    return(scalaInstall("2.12", global=global))
   }
   if ( major.release == "2.12" ) version <- SCALA_212_VERSION
   else if ( major.release == "2.11" ) version <- SCALA_211_VERSION
